Risk Models
===========

SCORE2 Model
------------

.. automodule:: cvd_risk_calculator.models.score2
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: cvd_risk_calculator.models.score2.SCORE2
   :members:
   :special-members:

